% TropD find latitude of maximum of a given field
% Written by Ori Adam Mar.17.2017
% Syntax:
% >> Phi = TropD_Calculate_MaxLat(F,lat,n)
% Input:
% F = vector
% lat = ordinate vector, same length as F
% n (optional, default = 6): rank of moment used to calculate the position of max value (n >= 1)
% Output:
% Phi = location of maximum of F along lat

function Ymax = TropD_Calculate_MaxLat(F,lat,n)
if nargin <3
    n = 6         ; % Smoothing_rank. The result converges to max(F) for n --> inf
elseif ~isscalar(n) || n<1
    disp 'TropD_Calculate_MaxLat: ERROR: the smoothing parameter n must be a scalar >= 1'
    Ymax = [] ;
    return
end
n = double(n) ;
F = double(F) ;
if sum(isnan(F))
    try
        F = F - nanmin(F) ; % Shift lowest value to 0
        F = F/nanmax(F)   ; % Scale F between [0 1]
        Ymax = nantrapz(lat,F.^n.*lat)/nantrapz(lat,F.^n) ;
    catch % in case NaN-enabled functions such as nanmax and nanmean are not supported
        disp 'TropD_Calculate_MaxLat: ERROR: input field has F NaN values'
        Ymax = [] ;
        return
    end
else
    F = F - min(F) ; % Shift lowest value to 0
    F = F/max(F)   ; % Scale F between [0 1]
    Ymax = trapz(lat,F.^n.*lat)/trapz(lat,F.^n) ;
end

% QA
%  figure ;
%  plot(lat,F,'-b','linewidth',2) ; hold on
%  plot([Phi Phi],[min(F) max(F)],'--k') ;
