% TropD calculate seasonal means from monthly time series
% Written by Ori Adam Mar.18.2017
% Syntax 
% >> F = TropD_Calculate_Mon2Season(Fm,Season,m)
% Fm(time,lat,lev) or Fm(time,lat) or Fm(time,lev) = Monthly time series 
% Season = indices of months e.g., [1,2,12] for DJF,[1:12] for ANN, [6,7,8] for JJA
% m = the index of the first January of the time series (Default = 1)
% F = the annual time series of the seasonal means

function F = TropD_Calculate_Mon2Season(Fm,Season,m)
if nargin < 2
    m = 1 ; 
    Season = 1:12 ;
elseif nargin < 3
    m = 1 ; 
end
if max(Season) > 12 || min(Season) < 1
    F = [] ; 
    disp 'Season can only include indices from 1 to 12' ;
    return
end
End_Index = size(Fm,1)-m+1 - mod(size(Fm,1)-m+1,12) ; % remove unrepeated months
Fm = Fm(m:End_Index,:,:) ; 
F = Fm(m + Season(1) - 1:12:end,:,:) ;
if length(Season) > 1
for s = 2:length(Season)
F = F + Fm(m + Season(s) - 1:12:end,:,:) ; 
end
F = F/length(Season) ; 
end