% TropD find latitude of zero crossing
% Written by Ori Adam Mar.17.2017
% Find the first (with increasing index) zero crossing of the field F along the interval lat
% Syntax
% >>ZC = TropD_Calculate_ZeroCrossing(F,lat,Lat_Uncertainty)
% F = vector
% lat = latitude vector (same length as F)
% Lat_Uncertainty (optional): [Degrees latitude, default = 0] the minimal
% distance allowed between the first and second zero crossings of the same sign change
%                    for example, for Lat_Uncertainty = 10, if the most equatorward zero crossing is from positive to negative, 
%                    the function will return a Nan value if an additional zero crossings from positive to netagive is found within 10 degrees of that zero crossing.   
% ZC = latitude of zero crossing. Calculated by linear interpolation of the two nearest data points on either side of the zero crossing.

function ZC = TropD_Calculate_ZeroCrossing(F,lat,Lat_Uncertainty)
F = double(F) ; 
if nargin<3
Lat_Uncertainty = 0 ; % [Degrees latitude] the minimal distance allowed between the first and secong zero crossings of the same sign change
end
% Make sure a zero crossing exists
a = find(F>0) ; 
if length(a) == length(F) || isempty(a)
    ZC = nan ; 
    return ;
end
% find first zero crossing in index units
D = diff(sign(F)) ;
% If more than one zero crossing exist in proximity to the first zero crossing
a = find(abs(D)>0) ;
if length(a)>2 && abs(lat(a(3))-lat(a(1))) < Lat_Uncertainty
  ZC = nan ;
  return ;
end
a1 = find(abs(D)>0,1,'first') ; % in case F == 0 at a gridpoint 
if abs(D(a1))==1
zc = a1 + 1 ; 
else 
zc = a1 - F(a1)/(F(a1+1)-F(a1)) ; 
end
% translate into lat units
ZC = lat(1) + (zc-1)*(lat(end)-lat(1))/(length(lat)-1) ; 


% QA
% figure ; 
% plot(lat,F,'-b','linewidth',2) ; hold on
% plot(ZC,0,'*r') ; 
% plot(lat,lat*0,'-k','linewidth',1)

