% Example codes for using the TropD package to calculate tropical width metrics
% The code assumes that the current directory is ... TropD/MatlabCode/
%% Set display and meta parameters
y1 = 1979 ;
y2 = 2016 ;
time = linspace(y1,y2+1,12*(y2-y1+1)+1) ;
time = (time(1:end-1) + time(2:end))/2 ;
red_color       = [1   .3  .4 ] ;
orange_color    = [255 140 0  ]/256 ;
blue_color      = [0         0.4470    0.7410] ;
purple_color    = [0.4940    0.1840    0.5560] ;
green_color     = [0.4660    0.6740    0.1880] ;
lightblue_color = [0.3010    0.7450    0.9330] ;
maroon_color    = [0.6350    0.0780    0.1840] ;
% Ticks
Ytick1 = -60:1:60 ;
Ytick2 = -60:2:60 ;
Ytick5 = -60:5:60 ;
YtickLabels1 = {} ;
YtickLabels2 = {} ;
YtickLabels5 = {} ;
S0N = 'S0N' ;
for y = 1:2:length(Ytick1)
    if Ytick1(y)==0
        YtickLabels1(y)   = {'0'}  ;
    else
        YtickLabels1(y)   = {[int2str(abs(Ytick1(y))),S0N(sign(Ytick1(y))+2)]}  ;
    end
    if y<length(Ytick1) ; YtickLabels1(y+1) = {''}  ; end
end
for y = 1:2:length(Ytick2)
    if Ytick2(y)==0
        YtickLabels2(y)   = {'0'}  ;
    else
        YtickLabels2(y)   = {[int2str(abs(Ytick2(y))),S0N(sign(Ytick2(y))+2)]}  ;
    end
    if y<length(Ytick2) ; YtickLabels2(y+1) = {''}  ; end
end
for y = 1:2:length(Ytick5)
    if Ytick5(y)==0
        YtickLabels5(y)   = {'0'}  ;
    else
        YtickLabels5(y)   = {[int2str(abs(Ytick5(y))),S0N(sign(Ytick5(y))+2)]}  ;
    end
    if y<length(Ytick5) ; YtickLabels5(y+1) = {''}  ; end
end

%% 1) PSI -- Streamfunction zero crossing
V = ncread('../ValidationData/va.nc','va')    ; % read meridional velocity   V(time,lat,lev)
lat = ncread('../ValidationData/va.nc','lat') ; % latitude ordinate
lev = ncread('../ValidationData/va.nc','lev') ; % level ordinate
Phi_psi_nh = zeros(size(V,1),1)               ; % latitude of monthly NH Psi zero crossing
Phi_psi_sh = zeros(size(V,1),1)               ; % latitude of monthly SH Psi zero crossing
for j = 1:size(V,1)
    [Phi_psi_sh(j) , Phi_psi_nh(j)] = TropD_Metric_PSI(squeeze(V(j,:,:)),lat,lev) ; % Default method = 'Psi500'
end
% Calculate metric from annual mean
V_ANN = TropD_Calculate_Mon2Season(V,[1:12])  ; % calculate annual mean field
Phi_psi_nh_ANN = zeros(size(V_ANN,1),1)       ; % latitude of NH stream function zero crossing from annual mean V
Phi_psi_sh_ANN = zeros(size(V_ANN,1),1)       ; % latitude of SH stream function zero crossing from annual mean V
for j = 1:size(V_ANN,1)
    [Phi_psi_sh_ANN(j) , Phi_psi_nh_ANN(j)] = TropD_Metric_PSI(squeeze(V_ANN(j,:,:)),lat,lev) ;
end

figure ;
subplot 211
plot(time,Phi_psi_nh,'-','linewidth',1,'color',green_color) ; hold on
plot([y1:y2]+.5,Phi_psi_nh_ANN,'-','linewidth',2,'color',blue_color) ;
plot([y1:y2]+.5,TropD_Calculate_Mon2Season(Phi_psi_nh,[1:12]),'-k','linewidth',2) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off', ...
    'xtick',[1980:5:2020],'xticklabels',{''} ,...
    'ytick',Ytick5  ,'yticklabels',YtickLabels5)
ylabel({'NH \Psi_{500}';'latitude'})
xlim([y1 y2+1])
l = legend('Latitude of \Psi_{500} zero crossing from monthly mean V', ...
    'Latitude of \Psi_{500} zero crossing from annual mean V', ...
    'Latitude of \Psi_{500} zero crossing from annual means of monthly metric values') ;
set(l,'box','off','location','north')
subplot 212
plot(time,Phi_psi_sh,'-','linewidth',1,'color',green_color) ; hold on ;
plot([y1:y2]+.5,Phi_psi_sh_ANN,'-','linewidth',2,'color',blue_color) ;
plot([y1:y2]+.5,TropD_Calculate_Mon2Season(Phi_psi_sh,[1:12]),'-k','linewidth',2) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off', ...
    'xtick',[1980:5:2020], ...
    'ytick',Ytick5  ,'yticklabels',YtickLabels5)

xlim([y1 y2+1])
xlabel('Year','fontsize',14)
ylabel({'SH \Psi zero crossing';'latitude'})

% Introduce latitude unertainty condition: no additional zero crossing is allowed within 10 degrees
Phi_psi_nh_L = zeros(size(V,1),1)               ; % latitude of monthly NH Psi zero crossing
Phi_psi_sh_L = zeros(size(V,1),1)               ; % latitude of monthly SH Psi zero crossing
for j = 1:size(V,1)
    [Phi_psi_sh_L(j) , Phi_psi_nh_L(j)] = TropD_Metric_PSI(squeeze(V(j,:,:)),lat,lev,'Psi_500',10) ;
end

figure ;
plot(time,Phi_psi_nh,'-','linewidth',2,'color',green_color) ; hold on
plot(time(isnan(Phi_psi_nh_L)),Phi_psi_nh(isnan(Phi_psi_nh_L)),'*','markersize',10,'color',red_color) ; hold on
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off', ...
    'xtick',[1980:5:2020] ,'ytick',Ytick5  ,'yticklabels',YtickLabels5)
ylabel({'NH \Psi_{500}';'latitude'})
xlim([y1 y2+1])
l = legend('\Psi_{500} zero crossing from monthly mean V that qualify uncertainty criterion', ...
    '\Psi_{500} zero crossing from monthly mean V that fail uncertainty criterion') ;
set(l,'box','off','location','north')
xlabel('Year','fontsize',14)

%% 2) TPB -- Tropopause break latitude
T = ncread('../ValidationData/ta.nc','ta')    ; % read temperature   T(time,lat,lev)
Z = ncread('../ValidationData/zg.nc','zg')    ; % read potential height [m] Z(time,lat,lev)
lat = ncread('../ValidationData/ta.nc','lat') ; % latitude ordinate
lev = ncread('../ValidationData/ta.nc','lev') ; % level ordinate
Phi_tpb_nh = zeros(size(T,1),1)               ; % latitude of monthly NH tropopause break
Phi_tpb_sh = zeros(size(T,1),1)               ; % latitude of monthly SH tropopause break
for j = 1:size(T,1)
    [Phi_tpb_sh(j) , Phi_tpb_nh(j)] = TropD_Metric_TPB(squeeze(T(j,:,:)),lat,lev) ; % Defualt method = 'max_potemp'. Latitude of maximal difference between potential temperature at the tropopause level and the potential temperature at the surface
end
% Calculate tropopause break from annual mean
T_ANN = TropD_Calculate_Mon2Season(T,[1:12])  ; % calculate annual mean field
Z_ANN = TropD_Calculate_Mon2Season(Z,[1:12])  ; % calculate annual mean field
Phi_tpb_nh_ANN = zeros(size(T_ANN,1),1)       ; % latitude of NH tropopause break from annual mean T
Phi_tpb_sh_ANN = zeros(size(T_ANN,1),1)       ; % latitude of SH tropopause break from annual mean T
Phi_tpbZ_nh_ANN = zeros(size(T_ANN,1),1)       ; % latitude of NH tropopause break from annual mean T
Phi_tpbZ_sh_ANN = zeros(size(T_ANN,1),1)       ; % latitude of SH tropopause break from annual mean T
Phi_tpbT_nh_ANN = zeros(size(T_ANN,1),1)       ; % latitude of NH tropopause break from annual mean T
Phi_tpbT_sh_ANN = zeros(size(T_ANN,1),1)       ; % latitude of SH tropopause break from annual mean T
for j = 1:size(T_ANN,1)
    [Phi_tpb_sh_ANN(j)  , Phi_tpb_nh_ANN(j) ] = TropD_Metric_TPB(squeeze(T_ANN(j,:,:)),lat,lev,'max_gradient') ; % {Default} latitude of maximal poleward gradient
    [Phi_tpbT_sh_ANN(j) , Phi_tpbT_nh_ANN(j)] = TropD_Metric_TPB(squeeze(T_ANN(j,:,:)),lat,lev,'max_potemp') ; % latitude of maximal difference in potential temperature between the tropopase and surface    
    [Phi_tpbZ_sh_ANN(j) , Phi_tpbZ_nh_ANN(j)] = TropD_Metric_TPB(squeeze(T_ANN(j,:,:)),lat,lev,'cutoff',squeeze(Z_ANN(j,:,:)),15*1000) ; % CutoffHeight = 15km marks the height of the tropopause break
end

figure ;
subplot 211
plot(time,Phi_tpb_nh,'-','linewidth',1,'color',green_color) ; hold on
plot([y1:y2]+.5,Phi_tpb_nh_ANN,'-','linewidth',2,'color',blue_color) ;
plot([y1:y2]+.5,Phi_tpbZ_nh_ANN,'--','linewidth',1,'color',blue_color) ;
plot([y1:y2]+.5,Phi_tpbT_nh_ANN,'--','linewidth',1,'color',red_color) ;
plot([y1:y2]+.5,TropD_Calculate_Mon2Season(Phi_tpb_nh,[1:12]),'-k','linewidth',2) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off', ...
    'xtick',[1980:5:2020],'xticklabels',{''} ,...
    'ytick',Ytick5  ,'yticklabels',YtickLabels5)
ylabel({'NH tropopause break';'latitude'})
xlim([y1 y2+1])
l = legend('Latitude of tropopause break from monthly mean T -- potential temperature difference', ...
    'Latitude of tropopause break from annual mean T -- maximal gradient', ...
    'Latitude of tropopause break from annual mean T -- 15km cutoff height', ...
    'Latitude of tropopause break from annual mean T -- potential temperature difference', ...
    'Latitude of tropopause break from annual mean of monthly metric values -- potential temperature difference') ;
set(l,'box','off','location','north')
subplot 212
plot(time,Phi_tpb_sh,'-','linewidth',1,'color',green_color) ; hold on ;
plot([y1:y2]+.5,Phi_tpb_sh_ANN,'-','linewidth',2,'color',blue_color) ;
plot([y1:y2]+.5,Phi_tpbZ_sh_ANN,'--','linewidth',1,'color',blue_color) ;
plot([y1:y2]+.5,Phi_tpbT_sh_ANN,'--','linewidth',1,'color',red_color) ;
plot([y1:y2]+.5,TropD_Calculate_Mon2Season(Phi_tpb_sh,[1:12]),'-k','linewidth',2) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off', ...
    'xtick',[1980:5:2020], ...
    'ytick',Ytick5  ,'yticklabels',YtickLabels5)

xlim([y1 y2+1])
xlabel('Year','fontsize',14)
ylabel({'SH tropopause break';'latitude'})

%% 3) OLR -- OLR cutoff
% Note: OLR is assumed to be positive upwards and in units of W/m^2
olr = -ncread('../ValidationData/rlnt.nc','rlnt')      ; % read zonal mean monthly TOA outgoing longwave radiation olr(time,lat)
olrcs = -ncread('../ValidationData/rlntcs.nc','rlntcs'); % read zonal mean monthly clear-sky TOA outgoing longwave radiation olrcs(time,lat)
lat = ncread('../ValidationData/rlnt.nc','lat')        ; % latitude ordinate
olr_ANN   = TropD_Calculate_Mon2Season(olr,[1:12])     ; % calculate annual mean field
olrcs_ANN = TropD_Calculate_Mon2Season(olrcs,[1:12])   ; % calculate annual mean field
Phi_olr_nh = zeros(size(olr,1),1)                      ; % latitude of NH olr metric
Phi_olr_sh = zeros(size(olr,1),1)                      ; % latitude of SH olr metric
Phi_olr_nh_ANN = zeros(size(olr_ANN,1),1)              ; % latitude of NH olr metric from annual mean olr
Phi_olr_sh_ANN = zeros(size(olr_ANN,1),1)              ; % latitude of SH olr metric from annual mean olr
Phi_olrcs_nh = zeros(size(olr,1),1)                    ; % latitude of NH olr metric
Phi_olrcs_sh = zeros(size(olr,1),1)                    ; % latitude of SH olr metric
Phi_olrcs_nh_ANN = zeros(size(olr_ANN,1),1)            ; % latitude of NH olr metric from annual mean olr
Phi_olrcs_sh_ANN = zeros(size(olr_ANN,1),1)            ; % latitude of SH olr metric from annual mean olr
Phi_olr20_nh_ANN = zeros(size(olr_ANN,1),1)            ; % latitude of NH olr metric from annual mean olr - 20W/m^2 cutoff
Phi_olr20_sh_ANN = zeros(size(olr_ANN,1),1)            ; % latitude of SH olr metric from annual mean olr - 20W/m^2 cutoff
Phi_olr240_nh_ANN = zeros(size(olr_ANN,1),1)           ; % latitude of NH olr metric from annual mean olr   240W/m^2 cutoff
Phi_olr240_sh_ANN = zeros(size(olr_ANN,1),1)           ; % latitude of SH olr metric from annual mean olr   240W/m^2 cutoff
for j = 1:size(olr,1)
    [Phi_olr_sh(j)   , Phi_olr_nh(j)]   = TropD_Metric_OLR(squeeze(olr(j,:,:)),lat) ; % Default method = '250W'
    [Phi_olrcs_sh(j) , Phi_olrcs_nh(j)] = TropD_Metric_OLR(squeeze(olrcs(j,:,:)),lat) ;
end
for j = 1:size(olr_ANN,1)
    [Phi_olr_sh_ANN(j)   ,     Phi_olr_nh_ANN(j)]   = TropD_Metric_OLR(squeeze(olr_ANN(j,:,:)),lat)   ;
    [Phi_olrcs_sh_ANN(j) ,   Phi_olrcs_nh_ANN(j)]   = TropD_Metric_OLR(squeeze(olrcs_ANN(j,:,:)),lat) ;
    [Phi_olr20_sh_ANN(j) ,   Phi_olr20_nh_ANN(j)]   = TropD_Metric_OLR(squeeze(olr_ANN(j,:,:)),lat,'20W')   ;
    [Phi_olr240_sh_ANN(j),  Phi_olr240_nh_ANN(j)]   = TropD_Metric_OLR(squeeze(olr_ANN(j,:,:)),lat,'cutoff',240) ;
end

figure ;
subplot 211
plot(time,Phi_olr_nh,'-','linewidth',3,'color',green_color) ; hold on
plot(time,Phi_olrcs_nh,'-','linewidth',1,'color',green_color.*.5) ; hold on
plot([y1:y2]+.5,Phi_olr_nh_ANN,'-','linewidth',3,'color',blue_color) ;
plot([y1:y2]+.5,Phi_olrcs_nh_ANN,'-','linewidth',1,'color',blue_color.*.5) ;

set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off','xtick',[1980:5:2020],'xticklabels',{''},'ytick',Ytick2 ,'yticklabels',YtickLabels2)
ylabel('NH OLR cutoff latitude')
xlim([y1 y2+1])
l = legend('Latitude of OLR 250W/m^2 cutoff latitude from monthly OLR', ...
    'Latitude of OLR 250W/m^2 cutoff latitude from monthly clear-sky OLR', ...
    'Latitude of OLR 250W/m^2 cutoff latitude from annual mean OLR', ...
    'Latitude of OLR 250W/m^2 cutoff latitude from annual mean clear-sky OLR') ;
set(l,'box','off','location','north')
subplot 212
plot(time,Phi_olr_sh,'-','linewidth',3,'color',green_color) ; hold on
plot(time,Phi_olrcs_sh,'-','linewidth',1,'color',green_color*.5) ; hold on
plot([y1:y2]+.5,Phi_olr_sh_ANN,'-','linewidth',3,'color',blue_color) ;
plot([y1:y2]+.5,Phi_olrcs_sh_ANN,'-','linewidth',1,'color',blue_color*.5) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off','xtick',[1980:5:2020],'ytick',Ytick2,'yticklabels',YtickLabels2)
xlim([y1 y2+1])
xlabel('Year','fontsize',14)
ylabel('SH OLR cutoff latitude')



figure ;
subplot 211
hold on
plot([y1:y2]+.5,Phi_olr_nh_ANN,'-','linewidth',3,'color',blue_color.*0.5) ;
plot([y1:y2]+.5,Phi_olr240_nh_ANN,'-','linewidth',3,'color',blue_color) ;
plot([y1:y2]+.5,Phi_olr20_nh_ANN,'-','linewidth',3,'color',green_color) ;

set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off','xtick',[1980:5:2020],'xticklabels',{''},'ytick',Ytick2 ,'yticklabels',YtickLabels2)
ylabel('NH OLR cutoff latitude')
xlim([y1 y2+1])
l = legend('Latitude of OLR 250W/m^2 {default} cutoff latitude from annual-mean OLR', ...
           'Latitude of OLR 240W/m^2 cutoff latitude from annual-mean OLR', ...
           'Latitude of OLR -20W/m^2 cutoff latitude from annual-mean OLR') ; 
set(l,'box','off','location','north')
subplot 212
hold on
plot([y1:y2]+.5,Phi_olr_sh_ANN,'-','linewidth',3,'color',blue_color.*0.5) ;
plot([y1:y2]+.5,Phi_olr240_sh_ANN,'-','linewidth',3,'color',blue_color) ;
plot([y1:y2]+.5,Phi_olr20_sh_ANN,'-','linewidth',3,'color',green_color) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off','xtick',[1980:5:2020],'ytick',Ytick2,'yticklabels',YtickLabels2)
xlim([y1 y2+1])
xlabel('Year','fontsize',14)
ylabel('SH OLR cutoff latitude')

%% 4) STJ -- Subtropical Jet (STJ) latitude
U = ncread('../ValidationData/ua.nc','ua')    ; % read zonal wind   U(time,lat,lev)
lat = ncread('../ValidationData/ua.nc','lat') ; % latitude ordinate
lev = ncread('../ValidationData/ua.nc','lev') ; % level ordinate
% Calculate STJ latitude from annual mean
U_ANN = TropD_Calculate_Mon2Season(U,[1:12])  ; % calculate annual mean field
Phi_stj_nh_ANN_adj = zeros(size(U_ANN,1),1)   ; % latitude of NH STJ from annual mean U
Phi_stj_sh_ANN_adj = zeros(size(U_ANN,1),1)   ; % latitude of SH STJ from annual mean U
Phi_stj_nh_ANN_core = zeros(size(U_ANN,1),1)  ; % latitude of NH STJ from annual mean U
Phi_stj_sh_ANN_core = zeros(size(U_ANN,1),1)  ; % latitude of SH STJ from annual mean U

for j = 1:size(U_ANN,1)
    [Phi_stj_sh_ANN_adj(j) , Phi_stj_nh_ANN_adj(j)] = TropD_Metric_STJ(squeeze(U_ANN(j,:,:)),lat,lev) ; % Default method =  'adjusted'
    [Phi_stj_sh_ANN_core(j) , Phi_stj_nh_ANN_core(j)] = TropD_Metric_STJ(squeeze(U_ANN(j,:,:)),lat,lev,'core') ;
end

figure ;
subplot 211
plot([y1:y2]+.5,Phi_stj_nh_ANN_adj,'-','linewidth',2,'color',green_color) ; hold on
plot([y1:y2]+.5,Phi_stj_nh_ANN_core,'-','linewidth',2,'color',blue_color) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off', ...
    'xtick',[1980:5:2020],'xticklabels',{''} ,'ytick',Ytick2,'yticklabels',YtickLabels2)
ylabel('NH STJ latitude')
xlim([y1 y2+1])
l = legend('Latitude of STJ from anual mean U, using ''adjusted'' method', ...
    'Latitude of STJ from anual mean U, using ''core'' method') ;
set(l,'box','off','location','north')
subplot 212
plot([y1:y2]+.5,Phi_stj_sh_ANN_adj,'-','linewidth',2,'color',green_color) ; hold on
plot([y1:y2]+.5,Phi_stj_sh_ANN_core,'-','linewidth',2,'color',blue_color) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off','xtick',[1980:5:2020],'ytick',Ytick2,'yticklabels',YtickLabels2)

xlim([y1 y2+1])
xlabel('Year','fontsize',14)
ylabel('SH STJ latitude')

%% 5) EDJ -- Eddy Driven Jet (EDJ) latitude
U = ncread('../ValidationData/ua.nc','ua')    ; % read zonal wind   U(time,lat,lev)
lat = ncread('../ValidationData/ua.nc','lat') ; % latitude ordinate
lev = ncread('../ValidationData/ua.nc','lev') ; % level ordinate
Phi_edj_nh = zeros(size(U,1),1)               ; % latitude of monthly NH EDJ
Phi_edj_sh = zeros(size(U,1),1)               ; % latitude of monthly SH EDJ
for j = 1:size(U,1)
    [Phi_edj_sh(j) , Phi_edj_nh(j)] = TropD_Metric_EDJ(squeeze(U(j,:,:)),lat,lev,'max') ; % Default method = 'max'
end
% Calculate EDJ latitude from annual mean
U_ANN = TropD_Calculate_Mon2Season(U,[1:12])  ; % calculate annual mean field
Phi_edj_nh_ANN = zeros(size(U_ANN,1),1)       ; % latitude of NH EDJ from annual mean U
Phi_edj_sh_ANN = zeros(size(U_ANN,1),1)       ; % latitude of SH EDJ from annual mean U
for j = 1:size(U_ANN,1)
    [Phi_edj_sh_ANN(j) , Phi_edj_nh_ANN(j)] = TropD_Metric_EDJ(squeeze(U_ANN(j,:,:)),lat,lev) ;
end

figure ;
subplot 211
plot(time,Phi_edj_nh,'-','linewidth',1,'color',green_color) ; hold on
plot([y1:y2]+.5,Phi_edj_nh_ANN,'-','linewidth',2,'color',blue_color) ;
plot([y1:y2]+.5,TropD_Calculate_Mon2Season(Phi_edj_nh,[1:12]),'-k','linewidth',2) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off', ...
    'xtick',[1980:5:2020],'xticklabels',{''} ,'ytick',Ytick2 ,'yticklabels',YtickLabels2)
ylabel('NH EDJ latitude')
xlim([y1 y2+1])
l = legend('Latitude of EDJ from monthly mean U', ...
    'Latitude of EDJ from annual mean U', ...
    'Latitude of EDJ from annual mean of monthly metric values') ;
set(l,'box','off','location','north')
subplot 212
plot(time,Phi_edj_sh,'-','linewidth',1,'color',green_color) ; hold on ;
plot([y1:y2]+.5,Phi_edj_sh_ANN,'-','linewidth',2,'color',blue_color) ;
plot([y1:y2]+.5,TropD_Calculate_Mon2Season(Phi_edj_sh,[1:12]),'-k','linewidth',2) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off', ...
    'xtick',[1980:5:2020],'ytick',Ytick2,'yticklabels',YtickLabels2)
xlim([y1 y2+1])
xlabel('Year','fontsize',14)
ylabel('SH EDJ latitude')

%% 6) PE -- Precipitation minus evaporation subtropical zero crossing latitude
pr  = ncread('../ValidationData/pr.nc','pr')       ; % read zonal mean monthly precipitation pr(time,lat)
L = 2.5104e6                                       ; % Latent heat of vaporization
er  = -ncread('../ValidationData/hfls.nc','hfls')/L; % read zonal mean monthly evaporation drived from surface latent heat flux hfls(time,lat)
PE = pr - er ;
lat = ncread('../ValidationData/pr.nc','lat')      ; % latitude ordinate
PE_ANN = TropD_Calculate_Mon2Season(PE,[1:12])     ; % calculate annual mean field
Phi_pe_nh = zeros(size(pr,1),1)                    ; % latitude of NH PminusE metric
Phi_pe_sh = zeros(size(pr,1),1)                    ; % latitude of SH PminusE metric
Phi_pe_nh_ANN = zeros(size(PE_ANN,1),1)            ; % latitude of NH PminusE metric from annual mean PminusE
Phi_pe_sh_ANN = zeros(size(PE_ANN,1),1)            ; % latitude of SH PminusE metric from annual mean PminusE
for j = 1:size(PE,1)
    [Phi_pe_sh(j) , Phi_pe_nh(j)] = TropD_Metric_PE(squeeze(PE(j,:,:)),lat) ; % Default method = 'zero_crossing'
end
for j = 1:size(PE_ANN,1)
    [Phi_pe_sh_ANN(j) , Phi_pe_nh_ANN(j)] = TropD_Metric_PE(squeeze(PE_ANN(j,:,:)),lat) ;
end

figure ;
subplot 211
plot(time,Phi_pe_nh,'-','linewidth',2,'color',green_color) ; hold on
plot([y1:y2]+.5,Phi_pe_nh_ANN,'-','linewidth',2,'color',blue_color) ;
plot([y1:y2]+.5,TropD_Calculate_Mon2Season(Phi_pe_nh,[1:12]),'-k','linewidth',2) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off','xtick',[1980:5:2020],'xticklabels',{''} ,'ytick',Ytick2,'yticklabels',YtickLabels2)
ylabel('NH P - E zero-crossing')
xlim([y1 y2+1])
l = legend('Latitude of P minus E zero-crossing', ...
    'Latitude of P minus E zero-crossing from annual mean field', ...
    'Latitude of P minus E zero-crossing from annual mean of monthly metric') ;
set(l,'box','off','location','north')
subplot 212
plot(time,Phi_pe_sh,'-','linewidth',2,'color',green_color) ; hold on
plot([y1:y2]+.5,Phi_pe_sh_ANN,'-','linewidth',2,'color',blue_color) ;
plot([y1:y2]+.5,TropD_Calculate_Mon2Season(Phi_pe_sh,[1:12]),'-k','linewidth',2) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off','xtick',[1980:5:2020],'ytick',Ytick2,'yticklabels',YtickLabels2)
xlim([y1 y2+1])
xlabel('Year','fontsize',14)
ylabel('SH P - E zero-crossing')

%% 7) UAS -- Zonal surface wind subtropical zero crossing latitude
U = ncread('../ValidationData/ua.nc','ua')    ; % read zonal wind   U(time,lat,lev)
lat = ncread('../ValidationData/ua.nc','lat') ; % latitude ordinate
lev = ncread('../ValidationData/ua.nc','lev') ; % level ordinate
uas  = ncread('../ValidationData/uas.nc','uas')      ; % read zonal mean monthly surface zonal wind uas(time,lat)
uas_ANN = TropD_Calculate_Mon2Season(uas,[1:12])     ; % calculate annual mean field
U_ANN   = TropD_Calculate_Mon2Season(U,[1:12])       ; % calculate annual mean field
Phi_uas_nh = zeros(size(uas,1),1)                    ; % latitude of NH surface zonal wind metric
Phi_uas_sh = zeros(size(uas,1),1)                    ; % latitude of SH surface zonal wind metric
Phi_uas_nh_ANN = zeros(size(uas_ANN,1),1)            ; % latitude of NH surface zonal wind metric from annual mean surface zonal wind
Phi_uas_sh_ANN = zeros(size(uas_ANN,1),1)            ; % latitude of SH surface zonal wind metric from annual mean surface zonal wind
Phi_Uas_nh_ANN = zeros(size(uas_ANN,1),1)            ; % latitude of NH surface zonal wind metric from annual mean zonal wind (lat,lev)
Phi_Uas_sh_ANN = zeros(size(uas_ANN,1),1)            ; % latitude of SH surface zonal wind metric from annual mean zonal wind (lat,lev)
% The TropD_Metric_UAS metric accepts both 2D and 1D zonal wind. 
% For surface 1D wind, both of the following syntaxes are allowed and equivalent
% [Phi_sh , Phi_nh] = TropD_Metric_UAS(uas,lat) ;   
% [Phi_sh , Phi_nh] = TropD_Metric_UAS(uas,lat,1) ; 

for j = 1:size(uas,1)
    [Phi_uas_sh(j) , Phi_uas_nh(j)] = TropD_Metric_UAS(squeeze(uas(j,:,:)),lat) ; % Default method = 'zero_crossing'
end
for j = 1:size(uas_ANN,1)
    [Phi_uas_sh_ANN(j) , Phi_uas_nh_ANN(j)] = TropD_Metric_UAS(squeeze(uas_ANN(j,:,:)),lat) ;
    [Phi_Uas_sh_ANN(j) , Phi_Uas_nh_ANN(j)] = TropD_Metric_UAS(squeeze(U_ANN(j,:,:)),lat,lev) ;
end

figure ;
subplot 211
plot(time,Phi_uas_nh,'-','linewidth',2,'color',green_color) ; hold on
plot([y1:y2]+.5,Phi_uas_nh_ANN,'-','linewidth',2,'color',blue_color) ;
plot([y1:y2]+.5,Phi_Uas_nh_ANN,'-','linewidth',2,'color',red_color) ;
plot([y1:y2]+.5,TropD_Calculate_Mon2Season(Phi_uas_nh,[1:12]),'-k','linewidth',2) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off','xtick',[1980:5:2020],'xticklabels',{''} ,'ytick',Ytick2,'yticklabels',YtickLabels2)
ylabel('NH uas zero-crossing')
xlim([y1 y2+1])
l = legend('Latitude of surface zonal wind zero crossing', ...
    'Latitude of surface zonal wind zero crossing from annual mean field', ...
    'Latitude of 850 hPa zonal wind zero crossing from annual mean field', ...
    'Latitude of surface zonal wind zero crossing from annual mean of monthly metric') ;
set(l,'box','off','location','north')
subplot 212
plot(time,Phi_uas_sh,'-','linewidth',2,'color',green_color) ; hold on
plot([y1:y2]+.5,Phi_uas_sh_ANN,'-','linewidth',2,'color',blue_color) ;
plot([y1:y2]+.5,Phi_Uas_sh_ANN,'-','linewidth',2,'color',red_color) ;
plot([y1:y2]+.5,TropD_Calculate_Mon2Season(Phi_uas_sh,[1:12]),'-k','linewidth',2) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off','xtick',[1980:5:2020],'ytick',Ytick2,'yticklabels',YtickLabels2)

xlim([y1 y2+1])
xlabel('Year','fontsize',14)
ylabel('SH uas zero-crossing')

%% 8) PSL -- Sea-level Pressure Maximum
ps = ncread('../ValidationData/psl.nc','psl')    ; % read sea-level pressure   psl(time,lat)
lat = ncread('../ValidationData/psl.nc','lat')   ; % latitude ordinate
ps_DJF = TropD_Calculate_Mon2Season(ps,[1,2,12]) ; % calculate DJF means
ps_JJA = TropD_Calculate_Mon2Season(ps,[6,7,8])  ; % calculate JJA means
Phi_ps_DJF_nh = zeros(size(ps_DJF,1),1)          ; % latitude of monthly NH max surface pressure
Phi_ps_JJA_nh = zeros(size(ps_JJA,1),1)          ; % latitude of monthly NH max surface pressure
Phi_ps_DJF_sh = zeros(size(ps_DJF,1),1)          ; % latitude of monthly SH max surface pressure
Phi_ps_JJA_sh = zeros(size(ps_JJA,1),1)          ; % latitude of monthly SH max surface pressure
for j = 1:size(ps_DJF,1)
    [Phi_ps_DJF_sh(j) , Phi_ps_DJF_nh(j)] = TropD_Metric_PSL(squeeze(ps_DJF(j,:,:))',lat) ; % Default method = 'max'
end
for j = 1:size(ps_JJA,1)
    [Phi_ps_JJA_sh(j) , Phi_ps_JJA_nh(j)] = TropD_Metric_PSL(squeeze(ps_JJA(j,:,:))',lat) ;
end

figure ;
subplot 211
plot([y1:y2]+.5,Phi_ps_DJF_nh,'-','linewidth',2,'color',green_color) ; hold on
plot([y1:y2]+.5,Phi_ps_JJA_nh,'-','linewidth',2,'color',blue_color) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off', ...
    'xtick',[1980:5:2020],'ytick',Ytick1  ,'yticklabels',YtickLabels1)
ylabel('NH max psl latitude')
xlim([y1 y2+1])
l = legend('Latitude of max sea-level pressure during DJF', ...
    'Latitude of max sea-level pressure during JJA') ;
set(l,'box','off','location','south')

subplot 212
plot([y1:y2]+.5,Phi_ps_DJF_sh,'-','linewidth',2,'color',green_color) ; hold on
plot([y1:y2]+.5,Phi_ps_JJA_sh,'-','linewidth',2,'color',blue_color) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off', ...
    'xtick',[1980:5:2020],'ytick',Ytick1,'yticklabels',YtickLabels1)
ylabel('SH max psl latitude')
xlim([y1 y2+1])

%% 9) Compare annual mean metrics
% Psi500
V = ncread('../ValidationData/va.nc','va')    ; % read meridional velocity   V(time,lat,lev)
lat = ncread('../ValidationData/va.nc','lat') ; % latitude ordinate
lev = ncread('../ValidationData/va.nc','lev') ; % level ordinate
V_ANN = TropD_Calculate_Mon2Season(V,[1:12])  ; % calculate annual mean field
Phi_psi_nh_ANN = zeros(size(V_ANN,1),1)       ; % latitude of NH stream function zero crossing from annual mean T
Phi_psi_sh_ANN = zeros(size(V_ANN,1),1)       ; % latitude of SH stream function zero crossing from annual mean T
for j = 1:size(V_ANN,1)
    [Phi_psi_sh_ANN(j) , Phi_psi_nh_ANN(j)] = TropD_Metric_PSI(squeeze(V_ANN(j,:,:)),lat,lev) ;
end
% Tropopause break
T = ncread('../ValidationData/ta.nc','ta')    ; % read temperature   T(time,lat,lev)
T_ANN = TropD_Calculate_Mon2Season(T,[1:12])  ; % calculate annual mean field
Phi_tpb_nh_ANN = zeros(size(T_ANN,1),1)       ; % latitude of NH tropopause break from annual mean T
Phi_tpb_sh_ANN = zeros(size(T_ANN,1),1)       ; % latitude of SH tropopause break from annual mean T
for j = 1:size(T_ANN,1)
    [Phi_tpb_sh_ANN(j) , Phi_tpb_nh_ANN(j)] = TropD_Metric_TPB(squeeze(T_ANN(j,:,:)),lat,lev) ;
end
% Surface pressure max
ps = ncread('../ValidationData/psl.nc','psl')   ; % read sea-level pressure   psl(time,lat)
ps_ANN = TropD_Calculate_Mon2Season(ps,[1:12]) ; % calculate DJF means
Phi_ps_nh_ANN = zeros(size(ps_ANN,1),1)        ; % latitude of monthly SH max surface pressure
Phi_ps_sh_ANN = zeros(size(ps_ANN,1),1)        ; % latitude of monthly SH max surface pressure
for j = 1:size(ps_ANN,1)
    [Phi_ps_sh_ANN(j) , Phi_ps_nh_ANN(j)] = TropD_Metric_PSL(squeeze(ps_ANN(j,:,:))',lat) ;
end
% Eddy driven jet
U = ncread('../ValidationData/ua.nc','ua')    ; % read zonal wind   U(time,lat,lev)
U_ANN = TropD_Calculate_Mon2Season(U,[1:12])  ; % calculate annual mean field
Phi_edj_nh_ANN = zeros(size(U_ANN,1),1)       ; % latitude of NH EDJ from annual mean U
Phi_edj_sh_ANN = zeros(size(U_ANN,1),1)       ; % latitude of SH EDJ from annual mean U
for j = 1:size(U_ANN,1)
    [Phi_edj_sh_ANN(j) , Phi_edj_nh_ANN(j)] = TropD_Metric_EDJ(squeeze(U_ANN(j,:,:)),lat,lev) ;
end
% Subtropical jet
Phi_stj_nh_ANN = zeros(size(U_ANN,1),1)       ; % latitude of NH STJ from annual mean U
Phi_stj_sh_ANN = zeros(size(U_ANN,1),1)       ; % latitude of SH STJ from annual mean U
for j = 1:size(U_ANN,1)
    [Phi_stj_sh_ANN(j) , Phi_stj_nh_ANN(j)] = TropD_Metric_STJ(squeeze(U_ANN(j,:,:)),lat,lev) ;
end
% OLR
olr = -ncread('../ValidationData/rlnt.nc','rlnt')  ; % read zonal mean monthly TOA outgoing longwave radiation olr(time,lat)
olr_ANN = TropD_Calculate_Mon2Season(olr,[1:12])   ; % calculate annual mean field
Phi_olr_nh_ANN = zeros(size(olr_ANN,1),1)          ; % latitude of NH olr metric from annual mean olr
Phi_olr_sh_ANN = zeros(size(olr_ANN,1),1)          ; % latitude of SH olr metric from annual mean olr
for j = 1:size(olr_ANN,1)
    [Phi_olr_sh_ANN(j) , Phi_olr_nh_ANN(j)] = TropD_Metric_OLR(squeeze(olr_ANN(j,:,:)),lat) ;
end
% P minus E
pr  = ncread('../ValidationData/pr.nc','pr')       ; % read zonal mean monthly precipitation pr(time,lat)
L = 2.5104e6                                       ; % Latent heat of vaporization
er  = -ncread('../ValidationData/hfls.nc','hfls')/L; % read zonal mean monthly evaporation derived from surface latent heat fluxes
PE = pr - er ;
PE_ANN = TropD_Calculate_Mon2Season(PE,[1:12])     ; % calculate annual mean field
Phi_pe_nh_ANN = zeros(size(PE_ANN,1),1)            ; % latitude of NH PminusE metric from annual mean PminusE
Phi_pe_sh_ANN = zeros(size(PE_ANN,1),1)            ; % latitude of SH PminusE metric from annual mean PminusE
for j = 1:size(PE_ANN,1)
    [Phi_pe_sh_ANN(j) , Phi_pe_nh_ANN(j)] = TropD_Metric_PE(squeeze(PE_ANN(j,:,:)),lat) ;
end
% Surface winds
uas  = ncread('../ValidationData/uas.nc','uas')    ; % read zonal mean monthly surface zonal wind uas(time,lat)
uas_ANN = TropD_Calculate_Mon2Season(uas,[1:12])   ; % calculate annual mean field
Phi_uas_nh_ANN = zeros(size(uas_ANN,1),1)          ; % latitude of NH surface zonal wind metric from annual mean surface zonal wind
Phi_uas_sh_ANN = zeros(size(uas_ANN,1),1)          ; % latitude of SH surface zonal wind metric from annual mean surface zonal wind
for j = 1:size(uas_ANN,1)
    [Phi_uas_sh_ANN(j) , Phi_uas_nh_ANN(j)] = TropD_Metric_UAS(squeeze(uas_ANN(j,:,:)),lat) ;
end
%
figure ;
subplot 211
plot([y1:y2],Phi_psi_nh_ANN,'-','linewidth',2,'color',[0 0 0]) ; hold on
plot([y1:y2],Phi_tpb_nh_ANN,'-','linewidth',2,'color',green_color) ;
plot([y1:y2],Phi_edj_nh_ANN,'-','linewidth',2,'color',blue_color) ;
plot([y1:y2],Phi_stj_nh_ANN,'-','linewidth',2,'color',red_color) ;
plot([y1:y2],Phi_olr_nh_ANN,'-','linewidth',2,'color',lightblue_color) ;
plot([y1:y2],Phi_pe_nh_ANN ,'-','linewidth',2,'color',orange_color) ;
plot([y1:y2],Phi_uas_nh_ANN,'-','linewidth',2,'color',purple_color) ;
plot([y1:y2],Phi_ps_nh_ANN ,'--','linewidth',2,'color',maroon_color) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off','xtick',[1980:5:2020],'xticklabels',{''},'ytick',Ytick5,'yticklabels',YtickLabels5)
l = legend('PSI', 'TPB', 'EDJ','STJ','OLR','P-E','UAS','PSL') ;
set(l,'box','off','location','eastoutside')

ylabel('NH HC edge')
xlim([y1 y2+1])
ylim([25 50])
subplot 212
plot([y1:y2],Phi_psi_sh_ANN,'-','linewidth',2,'color',[0 0 0]) ; hold on
plot([y1:y2],Phi_tpb_sh_ANN,'-','linewidth',2,'color',green_color) ;
plot([y1:y2],Phi_edj_sh_ANN,'-','linewidth',2,'color',blue_color) ;
plot([y1:y2],Phi_stj_sh_ANN,'-','linewidth',2,'color',red_color) ;
plot([y1:y2],Phi_olr_sh_ANN,'-','linewidth',2,'color',lightblue_color) ;
plot([y1:y2],Phi_pe_sh_ANN ,'-','linewidth',2,'color',orange_color) ;
plot([y1:y2],Phi_uas_sh_ANN,'-','linewidth',2,'color',purple_color) ;
plot([y1:y2],Phi_ps_sh_ANN ,'--','linewidth',2,'color',maroon_color) ;
set(gca,'fontsize',12,'linewidth',2,'tickdir','out','box','off','xtick',[1980:5:2020],'ytick',Ytick5,'yticklabels',YtickLabels5)
l = legend('PSI', 'TPB', 'EDJ','STJ','OLR','P-E','UAS','PSL') ;
set(l,'box','off','location','eastoutside')
xlim([y1 y2+1])
xlabel('Year','fontsize',14)
ylabel('SH HC edge')

%% 10) Validate metrics
% Psi500
V = ncread('../ValidationData/va.nc','va')    ; % read meridional velocity   V(time,lat,lev)
lat = ncread('../ValidationData/va.nc','lat') ; % latitude ordinate
lev = ncread('../ValidationData/va.nc','lev') ; % level ordinate
V_ANN = TropD_Calculate_Mon2Season(V,[1:12])  ; % calculate annual mean field
Phi_psi_nh = zeros(size(V,1),1)               ; % monthly latitude of NH stream function zero crossing
Phi_psi_sh = zeros(size(V,1),1)               ; % monthly latitude of SH stream function zero crossing
Phi_psi_nh_ANN = zeros(size(V_ANN,1),1)       ; % latitude of NH stream function zero crossing from annual mean V
Phi_psi_sh_ANN = zeros(size(V_ANN,1),1)       ; % latitude of SH stream function zero crossing from annual mean V
for j = 1:size(V,1)
    [Phi_psi_sh(j) , Phi_psi_nh(j)] = TropD_Metric_PSI(squeeze(V(j,:,:)),lat,lev) ;
end
for j = 1:size(V_ANN,1)
    [Phi_psi_sh_ANN(j) , Phi_psi_nh_ANN(j)] = TropD_Metric_PSI(squeeze(V_ANN(j,:,:)),lat,lev) ;
end
Phi_nh = ncread('../ValidationMetrics/PSI_ANN.nc','PSI_NH') ;
Phi_sh = ncread('../ValidationMetrics/PSI_ANN.nc','PSI_SH') ;
if ~(std(Phi_nh-Phi_psi_nh_ANN)<1.e-10 && std(Phi_sh-Phi_psi_sh_ANN)< 1.e-10) % within roundoff error
    disp 'Warning: annual-mean Validation and calculated PSI metrics are NOT equal!'
else
    disp 'OK. Annual-mean Validation and calculated PSI metrics are the same!'
end
Phi_nh = ncread('../ValidationMetrics/PSI.nc','PSI_NH') ;
Phi_sh = ncread('../ValidationMetrics/PSI.nc','PSI_SH') ;
if ~(std(Phi_nh-Phi_psi_nh)<1.e-10 && std(Phi_sh-Phi_psi_sh)< 1.e-10) % within roundoff error
    disp 'Warning: monthly Validation and calculated PSI metrics are NOT equal!'
else
    disp 'OK. Monthly Validation and calculated PSI metrics are the same!'
end

% Tropopause break
T = ncread('../ValidationData/ta.nc','ta')    ; % read temperature   T(time,lat,lev)
T_ANN = TropD_Calculate_Mon2Season(T,[1:12])  ; % calculate annual mean field
Phi_tpb_nh = zeros(size(T,1),1)               ; % monthly latitude of NH tropopause break
Phi_tpb_sh = zeros(size(T,1),1)               ; % monthly latitude of SH tropopause break
Phi_tpb_nh_ANN = zeros(size(T_ANN,1),1)       ; % latitude of NH tropopause break from annual mean T
Phi_tpb_sh_ANN = zeros(size(T_ANN,1),1)       ; % latitude of SH tropopause break from annual mean T
for j = 1:size(T,1)
    [Phi_tpb_sh(j) , Phi_tpb_nh(j)] = TropD_Metric_TPB(squeeze(T(j,:,:)),lat,lev) ;
end
for j = 1:size(T_ANN,1)
    [Phi_tpb_sh_ANN(j) , Phi_tpb_nh_ANN(j)] = TropD_Metric_TPB(squeeze(T_ANN(j,:,:)),lat,lev) ;
end
Phi_nh = ncread('../ValidationMetrics/TPB_ANN.nc','TPB_NH') ;
Phi_sh = ncread('../ValidationMetrics/TPB_ANN.nc','TPB_SH') ;
if ~(std(Phi_nh-Phi_tpb_nh_ANN)<1.e-10 && std(Phi_sh-Phi_tpb_sh_ANN)< 1.e-10) % within roundoff error
    disp 'Warning: annual-mean Validation and calculated TPB metrics are NOT equal!'
else
    disp 'OK. Annual-mean Validation and calculated TPB metrics are the same!'
end
Phi_nh = ncread('../ValidationMetrics/TPB.nc','TPB_NH') ;
Phi_sh = ncread('../ValidationMetrics/TPB.nc','TPB_SH') ;
if ~(std(Phi_nh-Phi_tpb_nh)<1.e-10 && std(Phi_sh-Phi_tpb_sh)< 1.e-10) % within roundoff error
    disp 'Warning: monthly Validation and calculated TPB metrics are NOT equal!'
else
    disp 'OK. Monthly Validation and calculated TPB metrics are the same!'
end

% Surface pressure max (Invalid in NH)
ps = ncread('../ValidationData/psl.nc','psl')        ; % read sea level pressure   psl(time,lat)
ps_DJF = TropD_Calculate_Mon2Season(ps,[1,2,12])     ; % calculate DJF means
ps_JJA = TropD_Calculate_Mon2Season(ps,[6:8])        ; % calculate JJA means
ps_MAM = TropD_Calculate_Mon2Season(ps,[3:5])        ; % calculate MAM means
ps_SON = TropD_Calculate_Mon2Season(ps,[9:11])       ; % calculate SON means
Phi_ps_sh_DJF = zeros(size(ps_DJF,1),1)       ;
Phi_ps_sh_JJA = zeros(size(ps_JJA,1),1)       ;
Phi_ps_sh_MAM = zeros(size(ps_MAM,1),1)       ;
Phi_ps_sh_SON = zeros(size(ps_SON,1),1)       ;
Phi_ps_nh_DJF = zeros(size(ps_DJF,1),1)       ;
Phi_ps_nh_JJA = zeros(size(ps_JJA,1),1)       ;
Phi_ps_nh_MAM = zeros(size(ps_MAM,1),1)       ;
Phi_ps_nh_SON = zeros(size(ps_SON,1),1)       ;
for j = 1:size(ps_DJF,1)
    [Phi_ps_sh_DJF(j) , Phi_ps_nh_DJF(j)] = TropD_Metric_PSL(squeeze(ps_DJF(j,:,:))',lat) ;
end
for j = 1:size(ps_JJA,1)
    [Phi_ps_sh_JJA(j) , Phi_ps_nh_JJA(j)] = TropD_Metric_PSL(squeeze(ps_JJA(j,:,:))',lat) ;
end
for j = 1:size(ps_MAM,1)
    [Phi_ps_sh_MAM(j) , Phi_ps_nh_MAM(j)] = TropD_Metric_PSL(squeeze(ps_MAM(j,:,:))',lat) ;
end
for j = 1:size(ps_SON,1)
    [Phi_ps_sh_SON(j) , Phi_ps_nh_SON(j)] = TropD_Metric_PSL(squeeze(ps_SON(j,:,:))',lat) ;
end
Phi_sh = ncread('../ValidationMetrics/PSL_DJF.nc','PSL_SH') ;
Phi_nh = ncread('../ValidationMetrics/PSL_DJF.nc','PSL_NH') ;
if ~(std(Phi_sh-Phi_ps_sh_DJF)< 1.e-10) || ~(std(Phi_nh-Phi_ps_nh_DJF)< 1.e-10) % within roundoff error
    disp 'Warning: DJF Validation and calculated PSL metrics are NOT equal!'
else
    disp 'OK. DJF Validation and calculated PSL metrics are the same!'
end
Phi_sh = ncread('../ValidationMetrics/PSL_JJA.nc','PSL_SH') ;
Phi_nh = ncread('../ValidationMetrics/PSL_JJA.nc','PSL_NH') ;
if ~(std(Phi_sh-Phi_ps_sh_JJA)< 1.e-10) || ~(std(Phi_nh-Phi_ps_nh_JJA)< 1.e-10) % within roundoff error
    disp 'Warning: JJA Validation and calculated PSL metrics are NOT equal!'
else
    disp 'OK. JJA Validation and calculated PSL metrics are the same!'
end
Phi_sh = ncread('../ValidationMetrics/PSL_MAM.nc','PSL_SH') ;
Phi_nh = ncread('../ValidationMetrics/PSL_MAM.nc','PSL_NH') ;
if ~(std(Phi_sh-Phi_ps_sh_MAM)< 1.e-10)  ||  ~(std(Phi_nh-Phi_ps_nh_MAM)< 1.e-10) % within roundoff error
    disp 'Warning: MAM Validation and calculated PSL metrics are NOT equal!'
else
    disp 'OK. MAM Validation and calculated PSL metrics are the same!'
end
Phi_sh = ncread('../ValidationMetrics/PSL_SON.nc','PSL_SH') ;
Phi_nh = ncread('../ValidationMetrics/PSL_SON.nc','PSL_NH') ;
if ~(std(Phi_sh-Phi_ps_sh_SON)< 1.e-10)  ||  ~(std(Phi_nh-Phi_ps_nh_SON)< 1.e-10) % within roundoff error
    disp 'Warning: SON Validation and calculated PSL metrics are NOT equal!'
else
    disp 'OK. SON Validation and calculated PSL metrics are the same!'
end
% Eddy driven jet
U = ncread('../ValidationData/ua.nc','ua')    ; % read zonal wind   U(time,lat,lev)
U_ANN = TropD_Calculate_Mon2Season(U,[1:12])  ; % calculate annual mean field
Phi_edj_nh = zeros(size(U,1),1)               ; % monthly latitude of NH EDJ
Phi_edj_sh = zeros(size(U,1),1)               ; % monthly latitude of SH EDJ
Phi_edj_nh_ANN = zeros(size(U_ANN,1),1)       ; % latitude of NH EDJ from annual mean U
Phi_edj_sh_ANN = zeros(size(U_ANN,1),1)       ; % latitude of SH EDJ from annual mean U
for j = 1:size(U,1)
    [Phi_edj_sh(j) , Phi_edj_nh(j)] = TropD_Metric_EDJ(squeeze(U(j,:,:)),lat,lev) ;
end
for j = 1:size(U_ANN,1)
    [Phi_edj_sh_ANN(j) , Phi_edj_nh_ANN(j)] = TropD_Metric_EDJ(squeeze(U_ANN(j,:,:)),lat,lev) ;
end
Phi_nh = ncread('../ValidationMetrics/EDJ_ANN.nc','EDJ_NH') ;
Phi_sh = ncread('../ValidationMetrics/EDJ_ANN.nc','EDJ_SH') ;
if ~(std(Phi_nh-Phi_edj_nh_ANN)<1.e-10 && std(Phi_sh-Phi_edj_sh_ANN)< 1.e-10) % within roundoff error
    disp 'Warning: annual-mean Validation and calculated EDJ metrics are NOT equal!'
else
    disp 'OK. Annual-mean Validation and calculated EDJ metrics are the same!'
end
Phi_nh = ncread('../ValidationMetrics/EDJ.nc','EDJ_NH') ;
Phi_sh = ncread('../ValidationMetrics/EDJ.nc','EDJ_SH') ;
if ~(std(Phi_nh-Phi_edj_nh)<1.e-10 && std(Phi_sh-Phi_edj_sh)< 1.e-10) % within roundoff error
    disp 'Warning: monthly Validation and calculated EDJ metrics are NOT equal!'
else
    disp 'OK. Monthly Validation and calculated EDJ metrics are the same!'
end

% Subtropical jet
Phi_stj_nh = zeros(size(U,1),1)         ; % monthly latitude of NH STJ
Phi_stj_sh = zeros(size(U,1),1)         ; % monthly latitude of SH STJ
Phi_stj_nh_ANN = zeros(size(U_ANN,1),1) ; % latitude of NH STJ from annual mean U
Phi_stj_sh_ANN = zeros(size(U_ANN,1),1) ; % latitude of SH STJ from annual mean U
for j = 1:size(U,1)
    [Phi_stj_sh(j) , Phi_stj_nh(j)] = TropD_Metric_STJ(squeeze(U(j,:,:)),lat,lev) ;
end
for j = 1:size(U_ANN,1)
    [Phi_stj_sh_ANN(j) , Phi_stj_nh_ANN(j)] = TropD_Metric_STJ(squeeze(U_ANN(j,:,:)),lat,lev) ;
end
Phi_nh = ncread('../ValidationMetrics/STJ_ANN.nc','STJ_NH') ;
Phi_sh = ncread('../ValidationMetrics/STJ_ANN.nc','STJ_SH') ;
if ~(std(Phi_nh-Phi_stj_nh_ANN)<1.e-10 && std(Phi_sh-Phi_stj_sh_ANN)< 1.e-10) % within roundoff error
    disp 'Warning: annual-mean Validation and calculated STJ metrics are NOT equal!'
else
    disp 'OK. Annual-mean Validation and calculated STJ metrics are the same!'
end
Phi_nh = ncread('../ValidationMetrics/STJ.nc','STJ_NH') ;
Phi_sh = ncread('../ValidationMetrics/STJ.nc','STJ_SH') ;
if ~(std(Phi_nh-Phi_stj_nh)<1.e-10 && std(Phi_sh-Phi_stj_sh)< 1.e-10) % within roundoff error
    disp 'Warning: monthly Validation and calculated STJ metrics are NOT equal!'
else
    disp 'OK. Monthly Validation and calculated STJ metrics are the same!'
end

% OLR
olr = -ncread('../ValidationData/rlnt.nc','rlnt')  ; % read zonal mean monthly TOA outgoing longwave radiation olr(time,lat)
olr_ANN = TropD_Calculate_Mon2Season(olr,[1:12])   ; % calculate annual mean field
Phi_olr_nh = zeros(size(olr,1),1)                  ; % monthly latitude of NH olr metric
Phi_olr_sh = zeros(size(olr,1),1)                  ; % monthly latitude of SH olr metric
Phi_olr_nh_ANN = zeros(size(olr_ANN,1),1)          ; % latitude of NH olr metric from annual mean olr
Phi_olr_sh_ANN = zeros(size(olr_ANN,1),1)          ; % latitude of SH olr metric from annual mean olr
for j = 1:size(olr,1)
    [Phi_olr_sh(j) , Phi_olr_nh(j)] = TropD_Metric_OLR(squeeze(olr(j,:,:)),lat) ;
end
for j = 1:size(olr_ANN,1)
    [Phi_olr_sh_ANN(j) , Phi_olr_nh_ANN(j)] = TropD_Metric_OLR(squeeze(olr_ANN(j,:,:)),lat) ;
end
Phi_nh = ncread('../ValidationMetrics/OLR_ANN.nc','OLR_NH') ;
Phi_sh = ncread('../ValidationMetrics/OLR_ANN.nc','OLR_SH') ;
if ~(std(Phi_nh-Phi_olr_nh_ANN)<1.e-10 && std(Phi_sh-Phi_olr_sh_ANN)< 1.e-10) % within roundoff error
    disp 'Warning: annual-mean Validation and calculated OLR metrics are NOT equal!'
else
    disp 'OK. Annual-mean Validation and calculated OLR metrics are the same!'
end
Phi_nh = ncread('../ValidationMetrics/OLR.nc','OLR_NH') ;
Phi_sh = ncread('../ValidationMetrics/OLR.nc','OLR_SH') ;
if ~(std(Phi_nh-Phi_olr_nh)<1.e-10 && std(Phi_sh-Phi_olr_sh)< 1.e-10) % within roundoff error
    disp 'Warning: monthly Validation and calculated OLR metrics are NOT equal!'
else
    disp 'OK. Monthly Validation and calculated OLR metrics are the same!'
end

% P minus E
pr  = ncread('../ValidationData/pr.nc','pr')       ; % read zonal mean monthly precipitation pr(time,lat)
L = 2.5104e6                                       ; % Latent heat of vaporization
er  = -ncread('../ValidationData/hfls.nc','hfls')/L; % read zonal mean monthly evaporation drived from surface latent heat flux hfls(time,lat)
PE = pr - er ;
PE_ANN = TropD_Calculate_Mon2Season(PE,[1:12])     ; % calculate annual mean field
Phi_pe_nh = zeros(size(PE,1),1)                    ; % monthly latitude of NH PE metric
Phi_pe_sh = zeros(size(PE,1),1)                    ; % monthly latitude of SH PE metric
Phi_pe_nh_ANN = zeros(size(PE_ANN,1),1)            ; % latitude of NH PE metric from annual mean P minus E
Phi_pe_sh_ANN = zeros(size(PE_ANN,1),1)            ; % latitude of SH PE metric from annual mean P minus E
for j = 1:size(PE,1)
    [Phi_pe_sh(j) , Phi_pe_nh(j)] = TropD_Metric_PE(squeeze(PE(j,:,:)),lat) ;
end
for j = 1:size(PE_ANN,1)
    [Phi_pe_sh_ANN(j) , Phi_pe_nh_ANN(j)] = TropD_Metric_PE(squeeze(PE_ANN(j,:,:)),lat) ;
end
Phi_nh = ncread('../ValidationMetrics/PE_ANN.nc','PE_NH') ;
Phi_sh = ncread('../ValidationMetrics/PE_ANN.nc','PE_SH') ;
if ~(std(Phi_nh-Phi_pe_nh_ANN)<1.e-10 && std(Phi_sh-Phi_pe_sh_ANN)< 1.e-10) % within roundoff error
    disp 'Warning: annual-mean Validation and calculated P-E metrics are NOT equal!'
else
    disp 'OK. Annual-mean Validation and calculated P-E metrics are the same!'
end
Phi_nh = ncread('../ValidationMetrics/PE.nc','PE_NH') ;
Phi_sh = ncread('../ValidationMetrics/PE.nc','PE_SH') ;
if ~(std(Phi_nh-Phi_pe_nh)<1.e-10 && std(Phi_sh-Phi_pe_sh)< 1.e-10) % within roundoff error
    disp 'Warning: monthly Validation and calculated P-E metrics are NOT equal!'
else
    disp 'OK. Monthly Validation and calculated P-E metrics are the same!'
end

% Surface winds
uas  = ncread('../ValidationData/uas.nc','uas')    ; % read zonal mean monthly surface zonal wind uas(time,lat)
uas_ANN = TropD_Calculate_Mon2Season(uas,[1:12])   ; % calculate annual mean field
Phi_uas_nh = zeros(size(uas,1),1)                  ; % monthly latitude of NH surface zonal wind metric
Phi_uas_sh = zeros(size(uas,1),1)                  ; % monthly latitude of SH surface zonal wind metric
Phi_uas_nh_ANN = zeros(size(uas_ANN,1),1)          ; % latitude of NH surface zonal wind metric from annual mean surface zonal wind
Phi_uas_sh_ANN = zeros(size(uas_ANN,1),1)          ; % latitude of SH surface zonal wind metric from annual mean surface zonal wind
for j = 1:size(uas,1)
    [Phi_uas_sh(j) , Phi_uas_nh(j)] = TropD_Metric_UAS(squeeze(uas(j,:,:)),lat) ;
end
for j = 1:size(uas_ANN,1)
    [Phi_uas_sh_ANN(j) , Phi_uas_nh_ANN(j)] = TropD_Metric_UAS(squeeze(uas_ANN(j,:,:)),lat) ;
end
Phi_nh = ncread('../ValidationMetrics/UAS_ANN.nc','UAS_NH') ;
Phi_sh = ncread('../ValidationMetrics/UAS_ANN.nc','UAS_SH') ;
if ~(std(Phi_nh-Phi_uas_nh_ANN)<1.e-10 && std(Phi_sh-Phi_uas_sh_ANN)< 1.e-10) % within roundoff error
    disp 'Warning: annual-mean Validation and calculated UAS metrics are NOT equal!'
else
    disp 'OK. Annual-mean Validation and calculated UAS metrics are the same!'
end
Phi_nh = ncread('../ValidationMetrics/UAS.nc','UAS_NH') ;
Phi_sh = ncread('../ValidationMetrics/UAS.nc','UAS_SH') ;
if ~(std(Phi_nh-Phi_uas_nh)<1.e-10 && std(Phi_sh-Phi_uas_sh)< 1.e-10) % within roundoff error
    disp 'Warning: monthly Validation and calculated UAS metrics are NOT equal!'
else
    disp 'OK. Monthly Validation and calculated UAS metrics are the same!'
end

