% TropD PSL metric
% Latitude of maximum of the subtropical sea-level pressure
% Written by Ori Adam Mar.17.2017
% Methods:
% the latitude of maximum of sea-level pressure 

% Syntax:
% >> [PhiSH PhiNH] = TropD_Metric_PSL(ps,lat,method)
% Input:
% ps(lat) = sea-level pressure
% lat = equally spaced latitude column vector
% method (optional) = | 'max' {default} | 'peak'
% Output:
% PhiSH = latitude of subtropical sea-level pressure maximum in the SH
% PhiNH = latitude of subtropical sea-level pressure maximum in the NH

function [PhiSH , PhiNH] = TropD_Metric_PSL(ps,lat,method)

if nargin < 3
    method = 'max' ;
end

eq_boundary    = 15 ;
polar_boundary = 60 ;
if ~iscolumn(ps)
    ps = ps' ; 
end
if ~iscolumn(lat)
    lat = lat' ; 
end
switch method
    case 'max'
        PhiNH = TropD_Calculate_MaxLat(ps(lat>eq_boundary & lat < polar_boundary),lat(lat>eq_boundary & lat < polar_boundary)) ;
        PhiSH = TropD_Calculate_MaxLat(ps(lat>-polar_boundary & lat < -eq_boundary),lat(lat>-polar_boundary & lat < -eq_boundary)) ;
    case 'peak'
        PhiNH = TropD_Calculate_MaxLat(ps(lat>eq_boundary & lat < polar_boundary),lat(lat>eq_boundary & lat < polar_boundary),30) ; % for n>=30, result converges to max(F)
        PhiSH = TropD_Calculate_MaxLat(ps(lat>-polar_boundary & lat < -eq_boundary),lat(lat>-polar_boundary & lat < -eq_boundary),30) ;    
    otherwise
        disp(['TropD_Metric_PSL: ERROR: unrecognized method ''',method,''''])
        PhiNH = [] ;
        PhiSH = [] ;
        return
end

% QA
%figure ;
%plot(lat,ps,'-k','linewidth',2) ; hold on
%plot([PhiNH  PhiNH],[min(ps)  max(ps)],'--')
%plot([PhiSH  PhiSH],[min(ps)  max(ps)],'--')
%xlabel('Latitude','fontsize',14) ;
%ylabel('Surface Pressure','fontsize',14)
